pub struct VerifiedBlockDeliveryBatch {
pub deliveries: Vec<VerifiedBlockDelivery>,
pub dropped_since_last_drain: u64,
}Expand description
One atomic drain of verified delivery evidence and any overflow since the prior drain.
Dropped evidence is intentionally not recoverable or billable through this API. An application adapter must surface a non-zero count and must not infer a payment claim.
Fields
deliveries: Vec<VerifiedBlockDelivery>dropped_since_last_drain: u64Trait Implementations
Sourceimpl Clone for VerifiedBlockDeliveryBatch
impl Clone for VerifiedBlockDeliveryBatch
Sourcefn clone(&self) -> VerifiedBlockDeliveryBatch
fn clone(&self) -> VerifiedBlockDeliveryBatch
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VerifiedBlockDeliveryBatch
impl Debug for VerifiedBlockDeliveryBatch
Sourceimpl Default for VerifiedBlockDeliveryBatch
impl Default for VerifiedBlockDeliveryBatch
Sourcefn default() -> VerifiedBlockDeliveryBatch
fn default() -> VerifiedBlockDeliveryBatch
Returns the “default value” for a type. Read more
impl Eq for VerifiedBlockDeliveryBatch
impl StructuralPartialEq for VerifiedBlockDeliveryBatch