Module mock

Module mock 

Mock implementations for testing and simulation

Provides mock relay transport and peer connection factory that use in-memory channels instead of real Nostr relays and WebRTC.

Structs

MockConnectionFactory
Mock peer connection factory
MockDataChannel
Mock data channel using mpsc channels
MockRelay
Mock relay for in-memory signaling
MockRelayTransport
Mock relay transport using broadcast channels

Enums

MockLatencyMode

Functions

clear_channel_registry
Clear the channel registry (call between tests)