pub fn create_request_with_quote(
hash: &Hash,
htl: u8,
quote_id: u64,
) -> DataRequestExpand description
Create a request that references a previously accepted quote.
pub fn create_request_with_quote(
hash: &Hash,
htl: u8,
quote_id: u64,
) -> DataRequestCreate a request that references a previously accepted quote.