pub fn encode_request(req: &DataRequest) -> Vec<u8> ⓘExpand description
Encode a request message to wire format Uses named/map encoding for compatibility with hashtree-ts and to support optional fields
pub fn encode_request(req: &DataRequest) -> Vec<u8> ⓘEncode a request message to wire format Uses named/map encoding for compatibility with hashtree-ts and to support optional fields