pub fn encode_response(res: &DataResponse) -> Vec<u8> ⓘExpand description
Encode a response message to wire format Uses named/map encoding for compatibility with hashtree-ts and to support optional fields
pub fn encode_response(res: &DataResponse) -> Vec<u8> ⓘEncode a response message to wire format Uses named/map encoding for compatibility with hashtree-ts and to support optional fields