Module pubsub_strategy

Module pubsub_strategy 

Pure peer traffic and pubsub fanout scheduling strategies.

This module has no transport or runtime dependencies so content-hash responses, production pubsub, and deterministic simulations can exercise the same reciprocity ranking code.

Structs

OutboundJobCandidate
OutboundJobSelection
PeerTrafficSnapshot
PubsubCandidate
PubsubSchedulerConfig
PubsubSelection

Enums

PubsubSchedulingPolicy

Functions

reciprocal_upload_weight
reciprocal_virtual_finish
select_reciprocal_outbound_job
stable_pubsub_score