pub struct PeerTrafficSnapshot {
pub bytes_sent: u64,
pub bytes_received: u64,
pub useful_bytes_received: u64,
pub bandwidth_debt: f64,
}Fields
bytes_sent: u64bytes_received: u64useful_bytes_received: u64Bytes that matched local demand or downstream demand.
Raw ingress can be spam. Reciprocity weighting should only reward bytes from content we requested, pubsub streams we subscribed to, or data we forwarded for a peer with an active downstream interest.
bandwidth_debt: f64Trait Implementations
Sourceimpl Clone for PeerTrafficSnapshot
impl Clone for PeerTrafficSnapshot
Sourcefn clone(&self) -> PeerTrafficSnapshot
fn clone(&self) -> PeerTrafficSnapshot
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for PeerTrafficSnapshot
Sourceimpl Debug for PeerTrafficSnapshot
impl Debug for PeerTrafficSnapshot
Sourceimpl Default for PeerTrafficSnapshot
impl Default for PeerTrafficSnapshot
Sourcefn default() -> PeerTrafficSnapshot
fn default() -> PeerTrafficSnapshot
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for PeerTrafficSnapshot
impl PartialEq for PeerTrafficSnapshot
impl StructuralPartialEq for PeerTrafficSnapshot