Mock implementations for testing and simulation
Provides mock relay transport and peer connection factory that use in-memory channels instead of real Nostr relays and WebRTC.
Structs
- Mock
Connection Factory - Mock peer connection factory
- Mock
Data Channel - Mock data channel using mpsc channels
- Mock
Relay - Mock relay for in-memory signaling
- Mock
Relay Transport - Mock relay transport using broadcast channels
Enums
Functions
- clear_
channel_ registry - Clear the channel registry (call between tests)